==> mu19ksuba.db_2.2.0.tar.gz: mu19ksuba.db/man/mu19ksuba_dbconn.Rd <==
\name{mu19ksuba_dbconn}

\alias{mu19ksuba_dbconn}
\alias{mu19ksuba_dbfile}
\alias{mu19ksuba_dbschema}
\alias{mu19ksuba_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mu19ksuba_dbconn()
  mu19ksuba_dbfile()
  mu19ksuba_dbschema(file="", show.indices=FALSE)
  mu19ksuba_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mu19ksuba_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mu19ksuba_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mu19ksuba_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mu19ksuba_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mu19ksuba_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mu19ksuba_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mu19ksuba_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mu19ksuba_dbschema}: none (invisible \code{NULL}).

  \code{mu19ksuba_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mu19ksuba_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mu19ksuba_dbconn() was created with:
  dbConnect(SQLite(), dbname=mu19ksuba_dbfile(), cache_size=64000, synchronous=0)

  mu19ksuba_dbschema()

  mu19ksuba_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mu19ksuba.db_2.4.5.tar.gz: mu19ksuba.db/man/mu19ksuba_dbconn.Rd <==

\name{mu19ksuba_dbconn}

\alias{mu19ksuba_dbconn}
\alias{mu19ksuba_dbfile}
\alias{mu19ksuba_dbschema}
\alias{mu19ksuba_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mu19ksuba_dbconn()
  mu19ksuba_dbfile()
  mu19ksuba_dbschema(file="", show.indices=FALSE)
  mu19ksuba_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mu19ksuba_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mu19ksuba_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mu19ksuba_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mu19ksuba_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mu19ksuba_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mu19ksuba_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mu19ksuba_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mu19ksuba_dbschema}: none (invisible \code{NULL}).

  \code{mu19ksuba_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mu19ksuba_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mu19ksuba_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mu19ksuba_dbfile(), cache_size=64000,
  synchronous=0)

  mu19ksuba_dbschema()

  mu19ksuba_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
